Increased the timeout for waiting for `reaped` to be invoked.

Previously after the container process is reaped by the Docker
executor, we will wait 3 seconds for `reaped` to be invoked.
However in some cases (e.g., launch a Docker container to use
an external rexray volume), there will be more than 3 seconds
after the container process exits and before the `docker run`
command returns (i.e., `reaped` invoked). So in this patch,
the timeout is increased to 60 seconds.

Review: https://reviews.apache.org/r/66947/


Project: http://git-wip-us.apache.org/repos/asf/mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/mesos/commit/7647f17c
Tree: http://git-wip-us.apache.org/repos/asf/mesos/tree/7647f17c
Diff: http://git-wip-us.apache.org/repos/asf/mesos/diff/7647f17c

Branch: refs/heads/1.6.x
Commit: 7647f17cb69fd5572a4ac744db9b8d24486e51c6
Parents: 7c691eb
Author: Qian Zhang <[email protected]>
Authored: Mon May 7 13:48:39 2018 -0700
Committer: Gilbert Song <[email protected]>
Committed: Mon May 7 14:24:41 2018 -0700

----------------------------------------------------------------------
 src/docker/executor.cpp | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/mesos/blob/7647f17c/src/docker/executor.cpp
----------------------------------------------------------------------
diff --git a/src/docker/executor.cpp b/src/docker/executor.cpp
index 16509da..572594a 100644
--- a/src/docker/executor.cpp
+++ b/src/docker/executor.cpp
@@ -348,11 +348,11 @@ public:
               // lambda; ideally when the Docker issue mentioned above does
               // not occur, `reaped` will be invoked (i.e., the `docker run`
               // command returns) to get the actual exit status of the
               // container, so here we wait a few seconds for `reaped` to be
               // invoked. If `reaped` is not invoked within the timeout, that
               // means we hit that Docker issue.
               delay(
-                  Seconds(3),
+                  Seconds(60),
                   self(),
                   &Self::reapedContainer,
                   container.pid.get());
@@ -361,10 +361,10 @@ public:
             }));
         } else {
           // This is the case that the container process has already exited,
           // Similar to the above case, let's wait a few seconds for `reaped`
           // to be invoked.
           delay(
-              Seconds(3),
+              Seconds(60),
               self(),
               &Self::reapedContainer,
               None());
@@ -348,11 +348,11 @@ public:
               // not occur, `reaped` will be invoked (i.e., the `docker run`
               // command returns) to get the actual exit status of the
-              // container, so here we wait a few seconds for `reaped` to be
+              // container, so here we wait 60 seconds for `reaped` to be
               // invoked. If `reaped` is not invoked within the timeout, that
               // means we hit that Docker issue.
@@ -361,10 +361,10 @@ public:
         } else {
           // This is the case that the container process has already exited,
-          // Similar to the above case, let's wait a few seconds for `reaped`
+          // Similar to the above case, let's wait 60 seconds for `reaped`
           // to be invoked.
           delay(

Reply via email to